# tamer

## Getting Started

Fork the repository and clone it to your local machine. Then, run the following commands to rename all folders, files and variable from `tamer` to the name of your project:
  
```bash
```

## Scipts

The following scripts are available:
- `make style`: run the ruff fix
- `make check`: run the ruff check
- `make test`: run the tests
